@@ -1298,6 +1298,35 @@ ggit_direction_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_clone_local_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_CLONE_LOCAL_AUTO,
+			  "GGIT_CLONE_LOCAL_AUTO",
+			  "auto" },
+			{ GGIT_CLONE_LOCAL_LOCAL,
+			  "GGIT_CLONE_LOCAL_LOCAL",
+			  "local" },
+			{ GGIT_CLONE_LOCAL_NO_LOCAL,
+			  "GGIT_CLONE_LOCAL_NO_LOCAL",
+			  "no-local" },
+			{ GGIT_CLONE_LOCAL_NO_LINKS,
+			  "GGIT_CLONE_LOCAL_NO_LINKS",
+			  "no-links" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitCloneLocal"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
