@@ -287,4 +287,9 @@ ASSERT_ENUM (GGIT_CREDTYPE_SSH_INTERACTIVE, GIT_CREDTYPE_SSH_INTERACTIVE);
 ASSERT_ENUM (GGIT_DIRECTION_FETCH, GIT_DIRECTION_FETCH);
 ASSERT_ENUM (GGIT_DIRECTION_PUSH, GIT_DIRECTION_PUSH);
 
+ASSERT_ENUM (GGIT_CLONE_LOCAL_AUTO, GIT_CLONE_LOCAL_AUTO);
+ASSERT_ENUM (GGIT_CLONE_LOCAL_LOCAL, GIT_CLONE_LOCAL);
+ASSERT_ENUM (GGIT_CLONE_LOCAL_NO_LOCAL, GIT_CLONE_NO_LOCAL);
+ASSERT_ENUM (GGIT_CLONE_LOCAL_NO_LINKS, GIT_CLONE_LOCAL_NO_LINKS);
+
 /* ex:set ts=8 noet: */
