@@ -200,6 +200,13 @@ typedef struct _GgitReflogEntry GgitReflogEntry;
  */
 typedef struct _GgitRemoteHead GgitRemoteHead;
 
+/**
+ * GgitRemote:
+ *
+ * Represents a git remote.
+ */
+typedef struct _GgitRemote GgitRemote;
+
 /**
  * GgitRepository:
  *
@@ -939,6 +946,14 @@ typedef enum
 	GGIT_DIRECTION_PUSH  = 1
 } GgitDirection;
 
+typedef enum
+{
+	GGIT_CLONE_LOCAL_AUTO     = 0,
+	GGIT_CLONE_LOCAL_LOCAL    = 1,
+	GGIT_CLONE_LOCAL_NO_LOCAL = 2,
+	GGIT_CLONE_LOCAL_NO_LINKS = 3
+} GgitCloneLocal;
+
 /**
  * GgitConfigCallback:
  * @entry: a #GgitConfigEntry.
