@@ -27,6 +27,7 @@
 #include <libgit2-glib/ggit-branch.h>
 #include <libgit2-glib/ggit-clone-options.h>
 #include <libgit2-glib/ggit-commit.h>
+#include <libgit2-glib/ggit-commit-parents.h>
 #include <libgit2-glib/ggit-config-entry.h>
 #include <libgit2-glib/ggit-config.h>
 #include <libgit2-glib/ggit-cred.h>
@@ -41,6 +42,7 @@
 #include <libgit2-glib/ggit-diff-similarity-metric.h>
 #include <libgit2-glib/ggit-enum-types.h>
 #include <libgit2-glib/ggit-error.h>
+#include <libgit2-glib/ggit-fetch-options.h>
 #include <libgit2-glib/ggit-index-entry.h>
 #include <libgit2-glib/ggit-index-entry-resolve-undo.h>
 #include <libgit2-glib/ggit-index.h>
@@ -53,7 +55,6 @@
 #include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-oid.h>
 #include <libgit2-glib/ggit-patch.h>
-#include <libgit2-glib/ggit-push.h>
 #include <libgit2-glib/ggit-ref.h>
 #include <libgit2-glib/ggit-reflog-entry.h>
 #include <libgit2-glib/ggit-reflog.h>
@@ -65,6 +66,7 @@
 #include <libgit2-glib/ggit-signature.h>
 #include <libgit2-glib/ggit-status-options.h>
 #include <libgit2-glib/ggit-submodule.h>
+#include <libgit2-glib/ggit-submodule-update-options.h>
 #include <libgit2-glib/ggit-tag.h>
 #include <libgit2-glib/ggit-transfer-progress.h>
 #include <libgit2-glib/ggit-tree-builder.h>
